@@ -130,3 +130,14 @@ test_that("force", {
 })
 
 
+test_that("category column", {
+  
+  xx <- strat_map(x,sraster2 = sraster)
+  
+  expect_equal(ncol(sample_strat(xx, nSamp = 1000, method = "random")),3)
+  
+})
+
+
+
+
